@@ -2,10 +2,10 @@ from typing import Optional, Tuple
 
 import click
 
-from ..decorators import require_bins, require_login
+from ..decorators import loses_interactivity, require_bins, require_login
 from ..helpers.ansible import run_ansible
-from ..helpers.options import aws_profile_options
-from . import GlobalOptions
+from ..helpers.global_options import GlobalOptions
+from ..helpers.options import aws_profile_options, resource_argument
 from .sym import sym
 
 
@@ -13,10 +13,11 @@ from .sym import sym
     short_help="Run an Ansible playbook",
     context_settings={"ignore_unknown_options": True},
 )
-@click.argument("resource")
+@resource_argument
 @click.argument("command", nargs=-1)
 @aws_profile_options
 @click.make_pass_decorator(GlobalOptions)
+@loses_interactivity
 @require_bins("ansible-playbook", "aws", "session-manager-plugin")
 @require_login
 def ansible_playbook(
