@@ -2,6 +2,7 @@ import os
 import shlex
 import subprocess
 import sys
+import time
 from functools import wraps
 from subprocess import PIPE, CalledProcessError
 from typing import Any, Callable, Iterator, Optional, Sequence, Type, TypeVar, cast
@@ -11,7 +12,6 @@ import click
 from sentry_sdk.api import configure_scope
 from sentry_sdk.hub import init as sentry_init
 
-from .commands import GlobalOptions
 from .errors import (
     CliError,
     ErrorPatterns,
@@ -21,6 +21,7 @@ from .errors import (
 )
 from .helpers import segment
 from .helpers.config import Config
+from .helpers.global_options import GlobalOptions
 from .helpers.keywords_to_options import Argument, keywords_to_options
 from .helpers.os import has_command
 from .helpers.sentry import set_scope_context_os, set_scope_tag_org, set_scope_user
@@ -50,8 +51,7 @@ def run_subprocess(
         outputs = []
         for command in func(*args, **kwargs):
             command = keywords_to_options(command)
-            if options.debug:
-                print(f"exec: {shlex.join(command)}\n")
+            options.dprint(f"exec: {shlex.join(command)}\n")
             result = subprocess.run(
                 command,
                 check=True,
@@ -61,6 +61,7 @@ def run_subprocess(
                 text=True,
             )
             outputs.append(result.stdout)
+            options.dprint(f"stdout: {result.stdout}")
         if capture_output_:
             return outputs
 
@@ -72,8 +73,13 @@ def intercept_errors(
 ) -> Callable[[F], F]:
     def decorate(fn: F) -> F:
         @wraps(fn)
+        @click.make_pass_decorator(GlobalOptions)
         def wrapped(
-            *args: Any, quiet_: bool = False, suppress_: bool = False, **kwargs: Any
+            options: GlobalOptions,
+            *args: Any,
+            quiet_: bool = False,
+            suppress_: bool = False,
+            **kwargs: Any,
         ) -> Any:
             try:
                 return fn(*args, **kwargs)
@@ -82,6 +88,8 @@ def intercept_errors(
                 raise_if_match(patterns, message)
                 if not (quiet or quiet_):
                     sys.stderr.write(message)
+                else:
+                    options.dprint(f"error message: {message}")
                 if suppress or suppress_:
                     raise SuppressedError(err) from err
                 else:
@@ -168,3 +176,23 @@ def setup_sentry(**kwargs: Any) -> Callable[[F], F]:
         return cast(F, wrapped)
 
     return decorator
+
+
+def retry(*exceptions, count: int = 2, delay: int = None, check_ex=lambda _: True):
+    def decorator(fn: F) -> F:
+        @wraps(fn)
+        def wrapped(*args, **kwargs):
+            tries = 0
+            while tries < count:
+                tries += 1
+                try:
+                    return fn(*args, **kwargs)
+                except exceptions as ex:
+                    if not check_ex(ex) or tries == count:
+                        raise
+                    if delay:
+                        time.sleep(delay)
+
+        return cast(F, wrapped)
+
+    return decorator
