@@ -19,7 +19,7 @@ class AwsProfile(SAMLClient):
     setup_help = f"Set up your profile in `{str(AwsCredentialsPath)}`."
 
     resource: str
-    debug: bool
+    options: 'GlobalOptions'
 
     @classmethod
     def validate_resource(cls, resource: str):
